/****************************************************************************
** Meta object code from reading C++ file 'actionmodel_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kirigami-app-components-1.0.2/src/actioncollection/actionmodel_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'actionmodel_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15KirigamiActions11ActionModelE_t {};
} // unnamed namespace

template <> constexpr inline auto KirigamiActions::ActionModel::qt_create_metaobjectdata<qt_meta_tag_ZN15KirigamiActions11ActionModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KirigamiActions::ActionModel",
        "QML.Element",
        "ActionModel",
        "collectionNameChanged",
        "",
        "name",
        "shownActionsChanged",
        "KirigamiActions::ActionModel::ShownActions",
        "shown",
        "save",
        "reset",
        "QModelIndex",
        "index",
        "resetAll",
        "collectionName",
        "shownActions",
        "ShownActions",
        "AllActions",
        "ActiveActions",
        "Role",
        "ActionDescriptionRole",
        "ActionInstancesRole",
        "ActionCollectionRole",
        "ShortcutRole",
        "AlternateShortcutRole"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'collectionNameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'shownActionsChanged'
        QtMocHelpers::SignalData<void(KirigamiActions::ActionModel::ShownActions)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Method 'save'
        QtMocHelpers::MethodData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'reset'
        QtMocHelpers::MethodData<void(const QModelIndex &)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Method 'resetAll'
        QtMocHelpers::MethodData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'collectionName'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 0),
        // property 'shownActions'
        QtMocHelpers::PropertyData<enum ShownActions>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 1),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ShownActions'
        QtMocHelpers::EnumData<enum ShownActions>(16, 16, QMC::EnumFlags{}).add({
            {   17, ShownActions::AllActions },
            {   18, ShownActions::ActiveActions },
        }),
        // enum 'Role'
        QtMocHelpers::EnumData<enum Role>(19, 19, QMC::EnumFlags{}).add({
            {   20, Role::ActionDescriptionRole },
            {   21, Role::ActionInstancesRole },
            {   22, Role::ActionCollectionRole },
            {   23, Role::ShortcutRole },
            {   24, Role::AlternateShortcutRole },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ActionModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KirigamiActions::ActionModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KirigamiActions11ActionModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KirigamiActions11ActionModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15KirigamiActions11ActionModelE_t>.metaTypes,
    nullptr
} };

void KirigamiActions::ActionModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ActionModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->collectionNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->shownActionsChanged((*reinterpret_cast<std::add_pointer_t<KirigamiActions::ActionModel::ShownActions>>(_a[1]))); break;
        case 2: _t->save(); break;
        case 3: _t->reset((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 4: _t->resetAll(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ActionModel::*)(const QString & )>(_a, &ActionModel::collectionNameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActionModel::*)(KirigamiActions::ActionModel::ShownActions )>(_a, &ActionModel::shownActionsChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->collectionName(); break;
        case 1: *reinterpret_cast<enum ShownActions*>(_v) = _t->shownActions(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCollectionName(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setShownActions(*reinterpret_cast<enum ShownActions*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KirigamiActions::ActionModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KirigamiActions::ActionModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KirigamiActions11ActionModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int KirigamiActions::ActionModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void KirigamiActions::ActionModel::collectionNameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KirigamiActions::ActionModel::shownActionsChanged(KirigamiActions::ActionModel::ShownActions _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
