/****************************************************************************
** Meta object code from reading C++ file 'standardactiondata_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kirigami-app-components-1.0.2/src/actioncollection/standardactiondata_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'standardactiondata_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15KirigamiActions18StandardActionDataE_t {};
} // unnamed namespace

template <> constexpr inline auto KirigamiActions::StandardActionData::qt_create_metaobjectdata<qt_meta_tag_ZN15KirigamiActions18StandardActionDataE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KirigamiActions::StandardActionData",
        "QML.Element",
        "auto",
        "standardActionChanged",
        "",
        "KirigamiActions::StandardActionData::StandardAction",
        "standardAction",
        "StandardAction",
        "ActionNone",
        "New",
        "Open",
        "OpenRecent",
        "Save",
        "SaveAs",
        "Revert",
        "Close",
        "Print",
        "PrintPreview",
        "Mail",
        "Quit",
        "Undo",
        "Redo",
        "Cut",
        "Copy",
        "Paste",
        "SelectAll",
        "Deselect",
        "Find",
        "FindNext",
        "FindPrev",
        "Replace",
        "ActualSize",
        "FitToPage",
        "FitToWidth",
        "FitToHeight",
        "ZoomIn",
        "ZoomOut",
        "Zoom",
        "Redisplay",
        "Up",
        "Back",
        "Forward",
        "Home",
        "Prior",
        "Next",
        "Goto",
        "GotoPage",
        "GotoLine",
        "FirstPage",
        "LastPage",
        "DocumentBack",
        "DocumentForward",
        "AddBookmark",
        "EditBookmarks",
        "Spelling",
        "ShowMenubar",
        "ShowToolbar",
        "ShowStatusbar",
        "KeyBindings",
        "Preferences",
        "ConfigureToolbars",
        "HelpContents",
        "WhatsThis",
        "ReportBug",
        "AboutApp",
        "AboutKDE",
        "ConfigureNotifications",
        "FullScreen",
        "Clear",
        "SwitchApplicationLanguage",
        "DeleteFile",
        "RenameFile",
        "MoveToTrash",
        "Donate",
        "HamburgerMenu"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'standardActionChanged'
        QtMocHelpers::SignalData<void(KirigamiActions::StandardActionData::StandardAction)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'standardAction'
        QtMocHelpers::PropertyData<enum StandardAction>(6, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final | QMC::Required, 0),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'StandardAction'
        QtMocHelpers::EnumData<enum StandardAction>(7, 7, QMC::EnumFlags{}).add({
            {    8, StandardAction::ActionNone },
            {    9, StandardAction::New },
            {   10, StandardAction::Open },
            {   11, StandardAction::OpenRecent },
            {   12, StandardAction::Save },
            {   13, StandardAction::SaveAs },
            {   14, StandardAction::Revert },
            {   15, StandardAction::Close },
            {   16, StandardAction::Print },
            {   17, StandardAction::PrintPreview },
            {   18, StandardAction::Mail },
            {   19, StandardAction::Quit },
            {   20, StandardAction::Undo },
            {   21, StandardAction::Redo },
            {   22, StandardAction::Cut },
            {   23, StandardAction::Copy },
            {   24, StandardAction::Paste },
            {   25, StandardAction::SelectAll },
            {   26, StandardAction::Deselect },
            {   27, StandardAction::Find },
            {   28, StandardAction::FindNext },
            {   29, StandardAction::FindPrev },
            {   30, StandardAction::Replace },
            {   31, StandardAction::ActualSize },
            {   32, StandardAction::FitToPage },
            {   33, StandardAction::FitToWidth },
            {   34, StandardAction::FitToHeight },
            {   35, StandardAction::ZoomIn },
            {   36, StandardAction::ZoomOut },
            {   37, StandardAction::Zoom },
            {   38, StandardAction::Redisplay },
            {   39, StandardAction::Up },
            {   40, StandardAction::Back },
            {   41, StandardAction::Forward },
            {   42, StandardAction::Home },
            {   43, StandardAction::Prior },
            {   44, StandardAction::Next },
            {   45, StandardAction::Goto },
            {   46, StandardAction::GotoPage },
            {   47, StandardAction::GotoLine },
            {   48, StandardAction::FirstPage },
            {   49, StandardAction::LastPage },
            {   50, StandardAction::DocumentBack },
            {   51, StandardAction::DocumentForward },
            {   52, StandardAction::AddBookmark },
            {   53, StandardAction::EditBookmarks },
            {   54, StandardAction::Spelling },
            {   55, StandardAction::ShowMenubar },
            {   56, StandardAction::ShowToolbar },
            {   57, StandardAction::ShowStatusbar },
            {   58, StandardAction::KeyBindings },
            {   59, StandardAction::Preferences },
            {   60, StandardAction::ConfigureToolbars },
            {   61, StandardAction::HelpContents },
            {   62, StandardAction::WhatsThis },
            {   63, StandardAction::ReportBug },
            {   64, StandardAction::AboutApp },
            {   65, StandardAction::AboutKDE },
            {   66, StandardAction::ConfigureNotifications },
            {   67, StandardAction::FullScreen },
            {   68, StandardAction::Clear },
            {   69, StandardAction::SwitchApplicationLanguage },
            {   70, StandardAction::DeleteFile },
            {   71, StandardAction::RenameFile },
            {   72, StandardAction::MoveToTrash },
            {   73, StandardAction::Donate },
            {   74, StandardAction::HamburgerMenu },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<StandardActionData, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KirigamiActions::StandardActionData::staticMetaObject = { {
    QMetaObject::SuperData::link<ActionData::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KirigamiActions18StandardActionDataE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KirigamiActions18StandardActionDataE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15KirigamiActions18StandardActionDataE_t>.metaTypes,
    nullptr
} };

void KirigamiActions::StandardActionData::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<StandardActionData *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->standardActionChanged((*reinterpret_cast<std::add_pointer_t<KirigamiActions::StandardActionData::StandardAction>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (StandardActionData::*)(KirigamiActions::StandardActionData::StandardAction )>(_a, &StandardActionData::standardActionChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum StandardAction*>(_v) = _t->standardAction(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setStandardAction(*reinterpret_cast<enum StandardAction*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KirigamiActions::StandardActionData::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KirigamiActions::StandardActionData::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KirigamiActions18StandardActionDataE_t>.strings))
        return static_cast<void*>(this);
    return ActionData::qt_metacast(_clname);
}

int KirigamiActions::StandardActionData::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ActionData::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void KirigamiActions::StandardActionData::standardActionChanged(KirigamiActions::StandardActionData::StandardAction _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
