/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<actiondata_p.h>)
#  include <actiondata_p.h>
#endif
#if __has_include(<actionmodel_p.h>)
#  include <actionmodel_p.h>
#endif
#if __has_include(<keysequencehelper_p.h>)
#  include <keysequencehelper_p.h>
#endif
#if __has_include(<qmlactioncollection_p.h>)
#  include <qmlactioncollection_p.h>
#endif
#if __has_include(<standardactiondata_p.h>)
#  include <standardactiondata_p.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_kirigami_actioncollection()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    QMetaType::fromType<KKeySequenceRecorder *>().id();
    qmlRegisterEnum<KKeySequenceRecorder::Patterns>("KKeySequenceRecorder::Patterns");
    qmlRegisterEnum<KKeySequenceRecorder::Pattern>("KKeySequenceRecorder::Pattern");
    QMetaType::fromType<KirigamiActions::ActionCollection *>().id();
    QMetaType::fromType<KirigamiActions::ActionCollectionAttached *>().id();
    qmlRegisterTypesAndRevisions<KirigamiActions::ActionData>("org.kde.kirigami.actioncollection", 1);
    qmlRegisterTypesAndRevisions<KirigamiActions::ActionDataGroup>("org.kde.kirigami.actioncollection", 1);
    qmlRegisterTypesAndRevisions<KirigamiActions::ActionModel>("org.kde.kirigami.actioncollection", 1);
    qmlRegisterEnum<KirigamiActions::ActionModel::ShownActions>("KirigamiActions::ActionModel::ShownActions");
    qmlRegisterEnum<KirigamiActions::ActionModel::Role>("KirigamiActions::ActionModel::Role");
    qmlRegisterTypesAndRevisions<KirigamiActions::IconGroup>("org.kde.kirigami.actioncollection", 1);
    qmlRegisterTypesAndRevisions<KirigamiActions::KeySequenceForeign>("org.kde.kirigami.actioncollection", 1);
    qmlRegisterEnum<QKeySequence::StandardKey>("QKeySequence::StandardKey");
    qmlRegisterEnum<QKeySequence::SequenceFormat>("QKeySequence::SequenceFormat");
    qmlRegisterEnum<QKeySequence::SequenceMatch>("QKeySequence::SequenceMatch");
    qmlRegisterTypesAndRevisions<KirigamiActions::KeySequenceHelper>("org.kde.kirigami.actioncollection", 1);
    qmlRegisterEnum<KirigamiActions::KeySequenceHelper::ShortcutTypes>("KirigamiActions::KeySequenceHelper::ShortcutTypes");
    qmlRegisterEnum<KirigamiActions::KeySequenceHelper::ShortcutType>("KirigamiActions::KeySequenceHelper::ShortcutType");
    qmlRegisterTypesAndRevisions<KirigamiActions::QmlActionCollection>("org.kde.kirigami.actioncollection", 1);
    qmlRegisterTypesAndRevisions<KirigamiActions::StandardActionData>("org.kde.kirigami.actioncollection", 1);
    qmlRegisterEnum<KirigamiActions::StandardActionData::StandardAction>("KirigamiActions::StandardActionData::StandardAction");
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    QMetaType::fromType<QAction *>().id();
    qmlRegisterEnum<QAction::MenuRole>("QAction::MenuRole");
    qmlRegisterEnum<QAction::Priority>("QAction::Priority");
    QMetaType::fromType<QActionGroup *>().id();
    qmlRegisterEnum<QActionGroup::ExclusionPolicy>("QActionGroup::ExclusionPolicy");
    QT_WARNING_POP
    qmlRegisterModule("org.kde.kirigami.actioncollection", 1, 0);
}

static const QQmlModuleRegistration orgkdekirigamiactioncollectionRegistration("org.kde.kirigami.actioncollection", qml_register_types_org_kde_kirigami_actioncollection);
