/****************************************************************************
** Meta object code from reading C++ file 'qmlactioncollection_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kirigami-app-components-1.0.2/src/actioncollection/qmlactioncollection_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qmlactioncollection_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15KirigamiActions24ActionCollectionAttachedE_t {};
} // unnamed namespace

template <> constexpr inline auto KirigamiActions::ActionCollectionAttached::qt_create_metaobjectdata<qt_meta_tag_ZN15KirigamiActions24ActionCollectionAttachedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KirigamiActions::ActionCollectionAttached",
        "collectionChanged",
        "",
        "actionChanged",
        "shortcutChanged",
        "collection",
        "action",
        "QVariant"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'collectionChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'actionChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shortcutChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'collection'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 0),
        // property 'action'
        QtMocHelpers::PropertyData<QVariant>(6, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ActionCollectionAttached, qt_meta_tag_ZN15KirigamiActions24ActionCollectionAttachedE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KirigamiActions::ActionCollectionAttached::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KirigamiActions24ActionCollectionAttachedE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KirigamiActions24ActionCollectionAttachedE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15KirigamiActions24ActionCollectionAttachedE_t>.metaTypes,
    nullptr
} };

void KirigamiActions::ActionCollectionAttached::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ActionCollectionAttached *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->collectionChanged(); break;
        case 1: _t->actionChanged(); break;
        case 2: _t->shortcutChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ActionCollectionAttached::*)()>(_a, &ActionCollectionAttached::collectionChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActionCollectionAttached::*)()>(_a, &ActionCollectionAttached::actionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActionCollectionAttached::*)()>(_a, &ActionCollectionAttached::shortcutChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->collection(); break;
        case 1: *reinterpret_cast<QVariant*>(_v) = _t->action(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCollection(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setAction(*reinterpret_cast<QVariant*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KirigamiActions::ActionCollectionAttached::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KirigamiActions::ActionCollectionAttached::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KirigamiActions24ActionCollectionAttachedE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KirigamiActions::ActionCollectionAttached::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void KirigamiActions::ActionCollectionAttached::collectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KirigamiActions::ActionCollectionAttached::actionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KirigamiActions::ActionCollectionAttached::shortcutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
namespace {
struct qt_meta_tag_ZN15KirigamiActions19QmlActionCollectionE_t {};
} // unnamed namespace

template <> constexpr inline auto KirigamiActions::QmlActionCollection::qt_create_metaobjectdata<qt_meta_tag_ZN15KirigamiActions19QmlActionCollectionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KirigamiActions::QmlActionCollection",
        "QML.Element",
        "ActionCollection",
        "QML.Attached",
        "ActionCollectionAttached",
        "DefaultProperty",
        "actions",
        "nameChanged",
        "",
        "name",
        "aboutToAddActionInstance",
        "position",
        "KirigamiActions::ActionData*",
        "action",
        "actionInstanceAdded",
        "aboutToRemoveActionInstance",
        "actionInstanceRemoved",
        "QQmlListProperty<KirigamiActions::ActionData>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(7, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'aboutToAddActionInstance'
        QtMocHelpers::SignalData<void(int, KirigamiActions::ActionData *)>(10, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 }, { 0x80000000 | 12, 13 },
        }}),
        // Signal 'actionInstanceAdded'
        QtMocHelpers::SignalData<void(int, KirigamiActions::ActionData *)>(14, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 }, { 0x80000000 | 12, 13 },
        }}),
        // Signal 'aboutToRemoveActionInstance'
        QtMocHelpers::SignalData<void(int, KirigamiActions::ActionData *)>(15, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 }, { 0x80000000 | 12, 13 },
        }}),
        // Signal 'actionInstanceRemoved'
        QtMocHelpers::SignalData<void(int, KirigamiActions::ActionData *)>(16, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 }, { 0x80000000 | 12, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'actions'
        QtMocHelpers::PropertyData<QQmlListProperty<KirigamiActions::ActionData>>(6, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant | QMC::Final),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<QmlActionCollection, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KirigamiActions::QmlActionCollection::staticMetaObject = { {
    QMetaObject::SuperData::link<ActionCollection::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KirigamiActions19QmlActionCollectionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KirigamiActions19QmlActionCollectionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15KirigamiActions19QmlActionCollectionE_t>.metaTypes,
    nullptr
} };

void KirigamiActions::QmlActionCollection::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QmlActionCollection *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->nameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->aboutToAddActionInstance((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KirigamiActions::ActionData*>>(_a[2]))); break;
        case 2: _t->actionInstanceAdded((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KirigamiActions::ActionData*>>(_a[2]))); break;
        case 3: _t->aboutToRemoveActionInstance((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KirigamiActions::ActionData*>>(_a[2]))); break;
        case 4: _t->actionInstanceRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KirigamiActions::ActionData*>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KirigamiActions::ActionData* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KirigamiActions::ActionData* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KirigamiActions::ActionData* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KirigamiActions::ActionData* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QmlActionCollection::*)(const QString & )>(_a, &QmlActionCollection::nameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlActionCollection::*)(int , KirigamiActions::ActionData * )>(_a, &QmlActionCollection::aboutToAddActionInstance, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlActionCollection::*)(int , KirigamiActions::ActionData * )>(_a, &QmlActionCollection::actionInstanceAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlActionCollection::*)(int , KirigamiActions::ActionData * )>(_a, &QmlActionCollection::aboutToRemoveActionInstance, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QmlActionCollection::*)(int , KirigamiActions::ActionData * )>(_a, &QmlActionCollection::actionInstanceRemoved, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<QQmlListProperty<KirigamiActions::ActionData>*>(_v) = _t->actionsProperty(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KirigamiActions::QmlActionCollection::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KirigamiActions::QmlActionCollection::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KirigamiActions19QmlActionCollectionE_t>.strings))
        return static_cast<void*>(this);
    return ActionCollection::qt_metacast(_clname);
}

int KirigamiActions::QmlActionCollection::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ActionCollection::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void KirigamiActions::QmlActionCollection::nameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KirigamiActions::QmlActionCollection::aboutToAddActionInstance(int _t1, KirigamiActions::ActionData * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void KirigamiActions::QmlActionCollection::actionInstanceAdded(int _t1, KirigamiActions::ActionData * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void KirigamiActions::QmlActionCollection::aboutToRemoveActionInstance(int _t1, KirigamiActions::ActionData * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void KirigamiActions::QmlActionCollection::actionInstanceRemoved(int _t1, KirigamiActions::ActionData * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}
QT_WARNING_POP
