/****************************************************************************
** Meta object code from reading C++ file 'actiondata_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kirigami-app-components-1.0.2/src/actioncollection/actiondata_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'actiondata_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15KirigamiActions15ActionDataGroupE_t {};
} // unnamed namespace

template <> constexpr inline auto KirigamiActions::ActionDataGroup::qt_create_metaobjectdata<qt_meta_tag_ZN15KirigamiActions15ActionDataGroupE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KirigamiActions::ActionDataGroup",
        "QML.Element",
        "auto"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ActionDataGroup, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KirigamiActions::ActionDataGroup::staticMetaObject = { {
    QMetaObject::SuperData::link<QActionGroup::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KirigamiActions15ActionDataGroupE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KirigamiActions15ActionDataGroupE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15KirigamiActions15ActionDataGroupE_t>.metaTypes,
    nullptr
} };

void KirigamiActions::ActionDataGroup::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ActionDataGroup *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KirigamiActions::ActionDataGroup::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KirigamiActions::ActionDataGroup::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KirigamiActions15ActionDataGroupE_t>.strings))
        return static_cast<void*>(this);
    return QActionGroup::qt_metacast(_clname);
}

int KirigamiActions::ActionDataGroup::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QActionGroup::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN15KirigamiActions9IconGroupE_t {};
} // unnamed namespace

template <> constexpr inline auto KirigamiActions::IconGroup::qt_create_metaobjectdata<qt_meta_tag_ZN15KirigamiActions9IconGroupE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KirigamiActions::IconGroup",
        "QML.Element",
        "anonymous",
        "nameChanged",
        "",
        "sourceChanged",
        "widthChanged",
        "heightChanged",
        "colorChanged",
        "cacheChanged",
        "name",
        "source",
        "width",
        "height",
        "color",
        "QColor",
        "cache"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sourceChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'widthChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'heightChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cacheChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'source'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'width'
        QtMocHelpers::PropertyData<qreal>(12, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'height'
        QtMocHelpers::PropertyData<qreal>(13, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'color'
        QtMocHelpers::PropertyData<QColor>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'cache'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<IconGroup, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KirigamiActions::IconGroup::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KirigamiActions9IconGroupE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KirigamiActions9IconGroupE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15KirigamiActions9IconGroupE_t>.metaTypes,
    nullptr
} };

void KirigamiActions::IconGroup::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<IconGroup *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->nameChanged(); break;
        case 1: _t->sourceChanged(); break;
        case 2: _t->widthChanged(); break;
        case 3: _t->heightChanged(); break;
        case 4: _t->colorChanged(); break;
        case 5: _t->cacheChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (IconGroup::*)()>(_a, &IconGroup::nameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconGroup::*)()>(_a, &IconGroup::sourceChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconGroup::*)()>(_a, &IconGroup::widthChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconGroup::*)()>(_a, &IconGroup::heightChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconGroup::*)()>(_a, &IconGroup::colorChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (IconGroup::*)()>(_a, &IconGroup::cacheChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->source(); break;
        case 2: *reinterpret_cast<qreal*>(_v) = _t->width(); break;
        case 3: *reinterpret_cast<qreal*>(_v) = _t->height(); break;
        case 4: *reinterpret_cast<QColor*>(_v) = _t->color(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->cache(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setSource(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setWidth(*reinterpret_cast<qreal*>(_v)); break;
        case 3: _t->setHeight(*reinterpret_cast<qreal*>(_v)); break;
        case 4: _t->setColor(*reinterpret_cast<QColor*>(_v)); break;
        case 5: _t->setCache(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KirigamiActions::IconGroup::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KirigamiActions::IconGroup::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KirigamiActions9IconGroupE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KirigamiActions::IconGroup::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void KirigamiActions::IconGroup::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KirigamiActions::IconGroup::sourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KirigamiActions::IconGroup::widthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KirigamiActions::IconGroup::heightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KirigamiActions::IconGroup::colorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KirigamiActions::IconGroup::cacheChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
namespace {
struct qt_meta_tag_ZN15KirigamiActions10ActionDataE_t {};
} // unnamed namespace

template <> constexpr inline auto KirigamiActions::ActionData::qt_create_metaobjectdata<qt_meta_tag_ZN15KirigamiActions10ActionDataE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KirigamiActions::ActionData",
        "QML.Element",
        "auto",
        "nameChanged",
        "",
        "name",
        "iconChanged",
        "icon",
        "shortcutChanged",
        "QVariant",
        "shortcut",
        "alternateShortcutChanged",
        "defaultShortcutChanged",
        "defaultShortcut",
        "defaultAlternateShortcutChanged",
        "actionGroupChanged",
        "QActionGroup*",
        "group",
        "actionChanged",
        "action",
        "changed",
        "KirigamiActions::IconGroup*",
        "defaultAlternateShortcut",
        "actionGroup",
        "data"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'iconChanged'
        QtMocHelpers::SignalData<void(const QString &)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'shortcutChanged'
        QtMocHelpers::SignalData<void(const QVariant &)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'alternateShortcutChanged'
        QtMocHelpers::SignalData<void(const QVariant &)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'defaultShortcutChanged'
        QtMocHelpers::SignalData<void(const QVariant &)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 13 },
        }}),
        // Signal 'defaultAlternateShortcutChanged'
        QtMocHelpers::SignalData<void(const QVariant &)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 13 },
        }}),
        // Signal 'actionGroupChanged'
        QtMocHelpers::SignalData<void(QActionGroup *)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Signal 'actionChanged'
        QtMocHelpers::SignalData<void(QObject *)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 19 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 0),
        // property 'icon'
        QtMocHelpers::PropertyData<KirigamiActions::IconGroup*>(7, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant | QMC::Final),
        // property 'defaultShortcut'
        QtMocHelpers::PropertyData<QVariant>(13, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 4),
        // property 'defaultAlternateShortcut'
        QtMocHelpers::PropertyData<QVariant>(22, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 5),
        // property 'action'
        QtMocHelpers::PropertyData<QObject*>(19, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'actionGroup'
        QtMocHelpers::PropertyData<QActionGroup*>(23, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 6),
        // property 'data'
        QtMocHelpers::PropertyData<QVariant>(24, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0x70000000 | 20),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ActionData, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KirigamiActions::ActionData::staticMetaObject = { {
    QMetaObject::SuperData::link<QAction::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KirigamiActions10ActionDataE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KirigamiActions10ActionDataE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15KirigamiActions10ActionDataE_t>.metaTypes,
    nullptr
} };

void KirigamiActions::ActionData::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ActionData *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->nameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->iconChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->shortcutChanged((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1]))); break;
        case 3: _t->alternateShortcutChanged((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1]))); break;
        case 4: _t->defaultShortcutChanged((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1]))); break;
        case 5: _t->defaultAlternateShortcutChanged((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1]))); break;
        case 6: _t->actionGroupChanged((*reinterpret_cast<std::add_pointer_t<QActionGroup*>>(_a[1]))); break;
        case 7: _t->actionChanged((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QActionGroup* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ActionData::*)(const QString & )>(_a, &ActionData::nameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActionData::*)(const QString & )>(_a, &ActionData::iconChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActionData::*)(const QVariant & )>(_a, &ActionData::shortcutChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActionData::*)(const QVariant & )>(_a, &ActionData::alternateShortcutChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActionData::*)(const QVariant & )>(_a, &ActionData::defaultShortcutChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActionData::*)(const QVariant & )>(_a, &ActionData::defaultAlternateShortcutChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActionData::*)(QActionGroup * )>(_a, &ActionData::actionGroupChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActionData::*)(QObject * )>(_a, &ActionData::actionChanged, 7))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KirigamiActions::IconGroup* >(); break;
        case 5:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QActionGroup* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<KirigamiActions::IconGroup**>(_v) = _t->icon(); break;
        case 2: *reinterpret_cast<QVariant*>(_v) = _t->defaultShortcut(); break;
        case 3: *reinterpret_cast<QVariant*>(_v) = _t->defaultAlternateShortcut(); break;
        case 4: *reinterpret_cast<QObject**>(_v) = _t->action(); break;
        case 5: *reinterpret_cast<QActionGroup**>(_v) = _t->actionGroup(); break;
        case 6: *reinterpret_cast<QVariant*>(_v) = _t->data(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setDefaultShortcut(*reinterpret_cast<QVariant*>(_v)); break;
        case 3: _t->setDefaultAlternateShortcut(*reinterpret_cast<QVariant*>(_v)); break;
        case 4: _t->setAction(*reinterpret_cast<QObject**>(_v)); break;
        case 5: _t->setActionGroupNotify(*reinterpret_cast<QActionGroup**>(_v)); break;
        case 6: _t->setData(*reinterpret_cast<QVariant*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KirigamiActions::ActionData::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KirigamiActions::ActionData::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KirigamiActions10ActionDataE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QAction::qt_metacast(_clname);
}

int KirigamiActions::ActionData::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAction::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void KirigamiActions::ActionData::nameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KirigamiActions::ActionData::iconChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KirigamiActions::ActionData::shortcutChanged(const QVariant & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KirigamiActions::ActionData::alternateShortcutChanged(const QVariant & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KirigamiActions::ActionData::defaultShortcutChanged(const QVariant & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KirigamiActions::ActionData::defaultAlternateShortcutChanged(const QVariant & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void KirigamiActions::ActionData::actionGroupChanged(QActionGroup * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void KirigamiActions::ActionData::actionChanged(QObject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
namespace CheckNotifySignalValidity_ZN15KirigamiActions10ActionDataE {
template<typename T> using has_nullary_changed = decltype(std::declval<T>().changed());
template<typename T> using has_unary_changed = decltype(std::declval<T>().changed(std::declval<QVariant>()));
static_assert(qxp::is_detected_v<has_nullary_changed, KirigamiActions::ActionData> || qxp::is_detected_v<has_unary_changed, KirigamiActions::ActionData>,
              "NOTIFY signal changed does not exist in class (or is private in its parent)");
}
QT_WARNING_POP
