// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "loggingcategory.h"


Q_LOGGING_CATEGORY(KirigamiActionCollectionLog, "kf.kirigami.actioncollection", QtWarningMsg)

